==> mktcenter-service-threetree-1.0-20250915.100642-13-sources.jar: com/bizvane/mktcenterservice/interfaces/tree3/MktActivityCertificationService.java <==
package com.bizvane.mktcenterservice.interfaces.tree3;

import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SaveOrUpdateActivityCertificationReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SelectPageActivityCertificationRecordReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SelectPageActivityCertificationReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.GetDetailActivityCertificationRespVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.SelectPageActivityCertificationRecordRespVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.SelectPageActivityCertificationRespVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;

public interface MktActivityCertificationService {
    ResponseData<String> saveOrUpdate(SaveOrUpdateActivityCertificationReqVO reqVO, SysAccountPO sysAccountPO);

    ResponseData<GetDetailActivityCertificationRespVO> getDetail(Long mktActivityCertificationId, SysAccountPO sysAccountPO);

    ResponseData<PageInfo<SelectPageActivityCertificationRespVO>> selectPage(SelectPageActivityCertificationReqVO reqVO, SysAccountPO sysAccountPO);

    ResponseData<String> disable(Long mktActivityCertificationId, SysAccountPO sysAccountPO);

    ResponseData<PageInfo<SelectPageActivityCertificationRecordRespVO>> selectRecordPage(SelectPageActivityCertificationRecordReqVO reqVO, SysAccountPO sysAccountPO);
}

==> mktcenter-service-threetree-1.0-20250917.081314-15-sources.jar: com/bizvane/mktcenterservice/interfaces/tree3/MktActivityCertificationService.java <==
package com.bizvane.mktcenterservice.interfaces.tree3;

import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.ActivityCertificationUploadPhoneZipReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SaveOrUpdateActivityCertificationReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SelectPageActivityCertificationRecordReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.SelectPageActivityCertificationReqVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.GetDetailActivityCertificationRespVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.SelectPageActivityCertificationRecordRespVO;
import com.bizvane.mktcenterservice.models.vo.tree3.respvo.SelectPageActivityCertificationRespVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;

public interface MktActivityCertificationService {
    ResponseData<String> saveOrUpdate(SaveOrUpdateActivityCertificationReqVO reqVO, SysAccountPO sysAccountPO);

    ResponseData<GetDetailActivityCertificationRespVO> getDetail(Long mktActivityCertificationId, SysAccountPO sysAccountPO);

    ResponseData<PageInfo<SelectPageActivityCertificationRespVO>> selectPage(SelectPageActivityCertificationReqVO reqVO, SysAccountPO sysAccountPO);

    ResponseData<String> disable(Long mktActivityCertificationId, SysAccountPO sysAccountPO);

    ResponseData<PageInfo<SelectPageActivityCertificationRecordRespVO>> selectRecordPage(SelectPageActivityCertificationRecordReqVO reqVO, SysAccountPO sysAccountPO);

    ResponseData<String> parseUploadZipFile(ActivityCertificationUploadPhoneZipReqVO reqVO, SysAccountPO sysAccountPO);
}
